==> skrooge_0.7.3.2.orig.tar.gz: skrooge-0.7.3.2/skgbasegui/skgwidget.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
 * This file is a class managing widget.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skgwidget.h"
#include "skgtraces.h"

#include <QtGui/QWidget>

SKGWidget::SKGWidget(SKGDocument* iDocument)
        : QWidget(), document(iDocument)
{
    SKGTRACEIN(5, "SKGWidget::SKGWidget");
}

SKGWidget::~SKGWidget()
{
    SKGTRACEIN(5, "SKGWidget::~SKGWidget");
    document=NULL;
}

SKGDocument * SKGWidget::getDocument() const
{
    return document;
}

QString SKGWidget::getState()
{
    return "";
}

QString SKGWidget::getDefaultStateAttribute()
{
    return "";
}

void SKGWidget::setState(const QString& /*iState*/ )
{
}

QWidget* SKGWidget::getDragWidget()
{
    QWidget* w=this->findChild<QWidget*>("kGroup");
    if (!w) w=this;
    return w;
}

#include "skgwidget.moc"

==> skrooge_0.9.92.orig.tar.gz: skrooge-0.9.92/skgbasegui/skgwidget.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
 * This file is a class managing widget.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skgwidget.h"
#include "skgtraces.h"

#include <QtGui/QWidget>

SKGWidget::SKGWidget(SKGDocument* iDocument)
    : QWidget(), m_document(iDocument)
{
    SKGTRACEIN(5, "SKGWidget::SKGWidget");
}

SKGWidget::~SKGWidget()
{
    SKGTRACEIN(5, "SKGWidget::~SKGWidget");
    m_document = NULL;
}

SKGDocument * SKGWidget::getDocument() const
{
    return m_document;
}

QString SKGWidget::getState()
{
    return "";
}

QString SKGWidget::getDefaultStateAttribute()
{
    return "";
}

void SKGWidget::setState(const QString& /*iState*/)
{
}

QWidget* SKGWidget::getDragWidget()
{
    QWidget* w = this->findChild<QWidget*>("kGroup");
    if(!w) w = this;
    return w;
}

#include "skgwidget.moc"
